package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WorkerLevelMapper;
import com.ruoyi.system.domain.WorkerLevel;
import com.ruoyi.system.service.IWorkerLevelService;

/**
 * 师傅等级配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class WorkerLevelServiceImpl implements IWorkerLevelService 
{
    @Autowired
    private WorkerLevelMapper workerLevelMapper;

    /**
     * 查询师傅等级配置
     * 
     * @param id 师傅等级配置主键
     * @return 师傅等级配置
     */
    @Override
    public WorkerLevel selectWorkerLevelById(Long id)
    {
        return workerLevelMapper.selectWorkerLevelById(id);
    }

    /**
     * 查询师傅等级配置列表
     * 
     * @param workerLevel 师傅等级配置
     * @return 师傅等级配置
     */
    @Override
    public List<WorkerLevel> selectWorkerLevelList(WorkerLevel workerLevel)
    {
        return workerLevelMapper.selectWorkerLevelList(workerLevel);
    }

    /**
     * 新增师傅等级配置
     * 
     * @param workerLevel 师傅等级配置
     * @return 结果
     */
    @Override
    public int insertWorkerLevel(WorkerLevel workerLevel)
    {
        return workerLevelMapper.insertWorkerLevel(workerLevel);
    }

    /**
     * 修改师傅等级配置
     * 
     * @param workerLevel 师傅等级配置
     * @return 结果
     */
    @Override
    public int updateWorkerLevel(WorkerLevel workerLevel)
    {
        return workerLevelMapper.updateWorkerLevel(workerLevel);
    }

    /**
     * 批量删除师傅等级配置
     * 
     * @param ids 需要删除的师傅等级配置主键
     * @return 结果
     */
    @Override
    public int deleteWorkerLevelByIds(Long[] ids)
    {
        return workerLevelMapper.deleteWorkerLevelByIds(ids);
    }

    /**
     * 删除师傅等级配置信息
     * 
     * @param id 师傅等级配置主键
     * @return 结果
     */
    @Override
    public int deleteWorkerLevelById(Long id)
    {
        return workerLevelMapper.deleteWorkerLevelById(id);
    }
}
