package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WorkerLevel;
import com.ruoyi.system.service.IWorkerLevelService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 师傅等级配置Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/WorkerLevel")
public class WorkerLevelController extends BaseController
{
    @Autowired
    private IWorkerLevelService workerLevelService;

    /**
     * 查询师傅等级配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevel:list')")
    @GetMapping("/list")
    public TableDataInfo list(WorkerLevel workerLevel)
    {
        startPage();
        List<WorkerLevel> list = workerLevelService.selectWorkerLevelList(workerLevel);
        return getDataTable(list);
    }

    /**
     * 导出师傅等级配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevel:export')")
    @Log(title = "师傅等级配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkerLevel workerLevel)
    {
        List<WorkerLevel> list = workerLevelService.selectWorkerLevelList(workerLevel);
        ExcelUtil<WorkerLevel> util = new ExcelUtil<WorkerLevel>(WorkerLevel.class);
        util.exportExcel(response, list, "师傅等级配置数据");
    }

    /**
     * 获取师傅等级配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevel:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(workerLevelService.selectWorkerLevelById(id));
    }

    /**
     * 新增师傅等级配置
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevel:add')")
    @Log(title = "师傅等级配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkerLevel workerLevel)
    {
        return toAjax(workerLevelService.insertWorkerLevel(workerLevel));
    }

    /**
     * 修改师傅等级配置
     *
     *
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevel:edit')")
    @Log(title = "师傅等级配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkerLevel workerLevel)
    {
        return toAjax(workerLevelService.updateWorkerLevel(workerLevel));
    }

    /**
     * 删除师傅等级配置
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevel:remove')")
    @Log(title = "师傅等级配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(workerLevelService.deleteWorkerLevelByIds(ids));
    }
}
